@echo off
SETLOCAL EnableDelayedExpansion

:: تنظیمات قابل تغییر
SET "configFile=backup_config.ini"

:: خواندن تنظیمات از فایل
if not exist "%configFile%" (
    echo Creating default configuration file...
    (
        echo [Settings]
        echo sourceFolder=D:\SamanSolution
        echo backupFolder=D:\Backup
        echo backupName=PublishBackup
        echo maxBackups=30
        echo excludeExtensions=-x*.rar -x*.tmp -x*.log -x*.zip -x*.pdf -x*.mp4
    ) > "%configFile%"
    echo Please edit "%configFile%" and run again
    pause
    exit /b
)

:: خواندن تنظیمات
for /f "tokens=1,2 delims==" %%A in ('findstr /i "^sourceFolder ^backupFolder ^backupName ^maxBackups ^excludeExtensions" "%configFile%"') do (
    if "%%A"=="sourceFolder" SET "sourceFolder=%%B"
    if "%%A"=="backupFolder" SET "backupFolder=%%B"
    if "%%A"=="backupName" SET "backupName=%%B"
    if "%%A"=="maxBackups" SET "maxBackups=%%B"
    if "%%A"=="excludeExtensions" SET "excludeExtensions=%%B"
)

:: ایجاد نام فایل بکاپ
SET "dateStr=%date:~-4,4%-%date:~-7,2%-%date:~-10,2%_%time:~0,2%-%time:~3,2%-%time:~6,2%"
SET "backupFile=%backupFolder%\%backupName%_%dateStr%.zip"

:: بررسی فولدر مبدا
if not exist "%sourceFolder%\" (
    echo ERROR: Source folder does not exist
    echo "%sourceFolder%"
    pause
    exit /b 1
)

:: ایجاد فولدر مقصد
if not exist "%backupFolder%\" (
    mkdir "%backupFolder%"
    if %ERRORLEVEL% neq 0 (
        echo ERROR: Could not create backup directory
        pause
        exit /b 1
    )
)

:: ایجاد لیست فایلهای حذف از بکاپ
SET "excludeFile=%temp%\exclude_list.txt"
(
    for %%e in (%excludeExtensions%) do echo *.%%e
) > "%excludeFile%"

:: اجرای بکاپ با 7-Zip (اگر نصب است)
if exist "%ProgramFiles%\WinRAR\Rar.exe" (
    echo Using WinRAR for backup...
	"%ProgramFiles%\WinRAR\Rar.exe" a -r %excludeExtensions% %backupFile% %sourceFolder%\* 

) else (
    echo Using PowerShell for backup...
    powershell -nologo -noprofile -command "& { Add-Type -A 'System.IO.Compression.FileSystem'; [IO.Compression.ZipFile]::CreateFromDirectory('%sourceFolder%', '%backupFile%'); }"
)

:: حذف فایل موقت
del "%excludeFile%"

:: مدیریت تعداد بکاپهای نگهداری شده


:: نمایش نتیجه
if exist "%backupFile%" (
    for %%F in ("%backupFile%") do set "sizeMB=%%~zF"
    set /a "sizeMB=!sizeMB!/1048576"
    echo Backup completed successfully!
    echo Location: "%backupFile%"
    echo Size: !sizeMB! MB
) else (
    echo Backup failed!
)

rem pause